# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class CreateVMBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'boot_disk': 'Disk',
        'boot_disk_image_id': 'str',
        'cpu_model': 'str',
        'custom_ssh_keys': 'list[str]',
        'data_center_id': 'str',
        'gpu_model': 'str',
        'gpus': 'int',
        'machine_type': 'str',
        'max_price_hr': 'Decimal',
        'memory_gib': 'int',
        'metadata': 'dict(str, str)',
        'nics': 'list[CreateVMRequestNIC]',
        'password': 'str',
        'security_group_ids': 'list[str]',
        'ssh_key_source': 'SshKeySource',
        'start_script': 'str',
        'storage_disk_ids': 'list[str]',
        'vcpus': 'int',
        'vm_id': 'str'
    }

    attribute_map = {
        'boot_disk': 'bootDisk',
        'boot_disk_image_id': 'bootDiskImageId',
        'cpu_model': 'cpuModel',
        'custom_ssh_keys': 'customSshKeys',
        'data_center_id': 'dataCenterId',
        'gpu_model': 'gpuModel',
        'gpus': 'gpus',
        'machine_type': 'machineType',
        'max_price_hr': 'maxPriceHr',
        'memory_gib': 'memoryGib',
        'metadata': 'metadata',
        'nics': 'nics',
        'password': 'password',
        'security_group_ids': 'securityGroupIds',
        'ssh_key_source': 'sshKeySource',
        'start_script': 'startScript',
        'storage_disk_ids': 'storageDiskIds',
        'vcpus': 'vcpus',
        'vm_id': 'vmId'
    }

    def __init__(self, boot_disk=None, boot_disk_image_id=None, cpu_model=None, custom_ssh_keys=None, data_center_id=None, gpu_model=None, gpus=None, machine_type=None, max_price_hr=None, memory_gib=None, metadata=None, nics=None, password=None, security_group_ids=None, ssh_key_source=None, start_script=None, storage_disk_ids=None, vcpus=None, vm_id=None, _configuration=None):  # noqa: E501
        """CreateVMBody - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._boot_disk = None
        self._boot_disk_image_id = None
        self._cpu_model = None
        self._custom_ssh_keys = None
        self._data_center_id = None
        self._gpu_model = None
        self._gpus = None
        self._machine_type = None
        self._max_price_hr = None
        self._memory_gib = None
        self._metadata = None
        self._nics = None
        self._password = None
        self._security_group_ids = None
        self._ssh_key_source = None
        self._start_script = None
        self._storage_disk_ids = None
        self._vcpus = None
        self._vm_id = None
        self.discriminator = None

        if boot_disk is not None:
            self.boot_disk = boot_disk
        self.boot_disk_image_id = boot_disk_image_id
        if cpu_model is not None:
            self.cpu_model = cpu_model
        if custom_ssh_keys is not None:
            self.custom_ssh_keys = custom_ssh_keys
        if data_center_id is not None:
            self.data_center_id = data_center_id
        if gpu_model is not None:
            self.gpu_model = gpu_model
        if gpus is not None:
            self.gpus = gpus
        if machine_type is not None:
            self.machine_type = machine_type
        if max_price_hr is not None:
            self.max_price_hr = max_price_hr
        if memory_gib is not None:
            self.memory_gib = memory_gib
        if metadata is not None:
            self.metadata = metadata
        if nics is not None:
            self.nics = nics
        if password is not None:
            self.password = password
        if security_group_ids is not None:
            self.security_group_ids = security_group_ids
        if ssh_key_source is not None:
            self.ssh_key_source = ssh_key_source
        if start_script is not None:
            self.start_script = start_script
        if storage_disk_ids is not None:
            self.storage_disk_ids = storage_disk_ids
        if vcpus is not None:
            self.vcpus = vcpus
        self.vm_id = vm_id

    @property
    def boot_disk(self):
        """Gets the boot_disk of this CreateVMBody.  # noqa: E501


        :return: The boot_disk of this CreateVMBody.  # noqa: E501
        :rtype: Disk
        """
        return self._boot_disk

    @boot_disk.setter
    def boot_disk(self, boot_disk):
        """Sets the boot_disk of this CreateVMBody.


        :param boot_disk: The boot_disk of this CreateVMBody.  # noqa: E501
        :type: Disk
        """

        self._boot_disk = boot_disk

    @property
    def boot_disk_image_id(self):
        """Gets the boot_disk_image_id of this CreateVMBody.  # noqa: E501


        :return: The boot_disk_image_id of this CreateVMBody.  # noqa: E501
        :rtype: str
        """
        return self._boot_disk_image_id

    @boot_disk_image_id.setter
    def boot_disk_image_id(self, boot_disk_image_id):
        """Sets the boot_disk_image_id of this CreateVMBody.


        :param boot_disk_image_id: The boot_disk_image_id of this CreateVMBody.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and boot_disk_image_id is None:
            raise ValueError("Invalid value for `boot_disk_image_id`, must not be `None`")  # noqa: E501

        self._boot_disk_image_id = boot_disk_image_id

    @property
    def cpu_model(self):
        """Gets the cpu_model of this CreateVMBody.  # noqa: E501


        :return: The cpu_model of this CreateVMBody.  # noqa: E501
        :rtype: str
        """
        return self._cpu_model

    @cpu_model.setter
    def cpu_model(self, cpu_model):
        """Sets the cpu_model of this CreateVMBody.


        :param cpu_model: The cpu_model of this CreateVMBody.  # noqa: E501
        :type: str
        """

        self._cpu_model = cpu_model

    @property
    def custom_ssh_keys(self):
        """Gets the custom_ssh_keys of this CreateVMBody.  # noqa: E501


        :return: The custom_ssh_keys of this CreateVMBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._custom_ssh_keys

    @custom_ssh_keys.setter
    def custom_ssh_keys(self, custom_ssh_keys):
        """Sets the custom_ssh_keys of this CreateVMBody.


        :param custom_ssh_keys: The custom_ssh_keys of this CreateVMBody.  # noqa: E501
        :type: list[str]
        """

        self._custom_ssh_keys = custom_ssh_keys

    @property
    def data_center_id(self):
        """Gets the data_center_id of this CreateVMBody.  # noqa: E501


        :return: The data_center_id of this CreateVMBody.  # noqa: E501
        :rtype: str
        """
        return self._data_center_id

    @data_center_id.setter
    def data_center_id(self, data_center_id):
        """Sets the data_center_id of this CreateVMBody.


        :param data_center_id: The data_center_id of this CreateVMBody.  # noqa: E501
        :type: str
        """

        self._data_center_id = data_center_id

    @property
    def gpu_model(self):
        """Gets the gpu_model of this CreateVMBody.  # noqa: E501


        :return: The gpu_model of this CreateVMBody.  # noqa: E501
        :rtype: str
        """
        return self._gpu_model

    @gpu_model.setter
    def gpu_model(self, gpu_model):
        """Sets the gpu_model of this CreateVMBody.


        :param gpu_model: The gpu_model of this CreateVMBody.  # noqa: E501
        :type: str
        """

        self._gpu_model = gpu_model

    @property
    def gpus(self):
        """Gets the gpus of this CreateVMBody.  # noqa: E501


        :return: The gpus of this CreateVMBody.  # noqa: E501
        :rtype: int
        """
        return self._gpus

    @gpus.setter
    def gpus(self, gpus):
        """Sets the gpus of this CreateVMBody.


        :param gpus: The gpus of this CreateVMBody.  # noqa: E501
        :type: int
        """

        self._gpus = gpus

    @property
    def machine_type(self):
        """Gets the machine_type of this CreateVMBody.  # noqa: E501


        :return: The machine_type of this CreateVMBody.  # noqa: E501
        :rtype: str
        """
        return self._machine_type

    @machine_type.setter
    def machine_type(self, machine_type):
        """Sets the machine_type of this CreateVMBody.


        :param machine_type: The machine_type of this CreateVMBody.  # noqa: E501
        :type: str
        """

        self._machine_type = machine_type

    @property
    def max_price_hr(self):
        """Gets the max_price_hr of this CreateVMBody.  # noqa: E501


        :return: The max_price_hr of this CreateVMBody.  # noqa: E501
        :rtype: Decimal
        """
        return self._max_price_hr

    @max_price_hr.setter
    def max_price_hr(self, max_price_hr):
        """Sets the max_price_hr of this CreateVMBody.


        :param max_price_hr: The max_price_hr of this CreateVMBody.  # noqa: E501
        :type: Decimal
        """

        self._max_price_hr = max_price_hr

    @property
    def memory_gib(self):
        """Gets the memory_gib of this CreateVMBody.  # noqa: E501


        :return: The memory_gib of this CreateVMBody.  # noqa: E501
        :rtype: int
        """
        return self._memory_gib

    @memory_gib.setter
    def memory_gib(self, memory_gib):
        """Sets the memory_gib of this CreateVMBody.


        :param memory_gib: The memory_gib of this CreateVMBody.  # noqa: E501
        :type: int
        """

        self._memory_gib = memory_gib

    @property
    def metadata(self):
        """Gets the metadata of this CreateVMBody.  # noqa: E501


        :return: The metadata of this CreateVMBody.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """Sets the metadata of this CreateVMBody.


        :param metadata: The metadata of this CreateVMBody.  # noqa: E501
        :type: dict(str, str)
        """

        self._metadata = metadata

    @property
    def nics(self):
        """Gets the nics of this CreateVMBody.  # noqa: E501


        :return: The nics of this CreateVMBody.  # noqa: E501
        :rtype: list[CreateVMRequestNIC]
        """
        return self._nics

    @nics.setter
    def nics(self, nics):
        """Sets the nics of this CreateVMBody.


        :param nics: The nics of this CreateVMBody.  # noqa: E501
        :type: list[CreateVMRequestNIC]
        """

        self._nics = nics

    @property
    def password(self):
        """Gets the password of this CreateVMBody.  # noqa: E501


        :return: The password of this CreateVMBody.  # noqa: E501
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """Sets the password of this CreateVMBody.


        :param password: The password of this CreateVMBody.  # noqa: E501
        :type: str
        """

        self._password = password

    @property
    def security_group_ids(self):
        """Gets the security_group_ids of this CreateVMBody.  # noqa: E501


        :return: The security_group_ids of this CreateVMBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._security_group_ids

    @security_group_ids.setter
    def security_group_ids(self, security_group_ids):
        """Sets the security_group_ids of this CreateVMBody.


        :param security_group_ids: The security_group_ids of this CreateVMBody.  # noqa: E501
        :type: list[str]
        """

        self._security_group_ids = security_group_ids

    @property
    def ssh_key_source(self):
        """Gets the ssh_key_source of this CreateVMBody.  # noqa: E501


        :return: The ssh_key_source of this CreateVMBody.  # noqa: E501
        :rtype: SshKeySource
        """
        return self._ssh_key_source

    @ssh_key_source.setter
    def ssh_key_source(self, ssh_key_source):
        """Sets the ssh_key_source of this CreateVMBody.


        :param ssh_key_source: The ssh_key_source of this CreateVMBody.  # noqa: E501
        :type: SshKeySource
        """

        self._ssh_key_source = ssh_key_source

    @property
    def start_script(self):
        """Gets the start_script of this CreateVMBody.  # noqa: E501


        :return: The start_script of this CreateVMBody.  # noqa: E501
        :rtype: str
        """
        return self._start_script

    @start_script.setter
    def start_script(self, start_script):
        """Sets the start_script of this CreateVMBody.


        :param start_script: The start_script of this CreateVMBody.  # noqa: E501
        :type: str
        """

        self._start_script = start_script

    @property
    def storage_disk_ids(self):
        """Gets the storage_disk_ids of this CreateVMBody.  # noqa: E501


        :return: The storage_disk_ids of this CreateVMBody.  # noqa: E501
        :rtype: list[str]
        """
        return self._storage_disk_ids

    @storage_disk_ids.setter
    def storage_disk_ids(self, storage_disk_ids):
        """Sets the storage_disk_ids of this CreateVMBody.


        :param storage_disk_ids: The storage_disk_ids of this CreateVMBody.  # noqa: E501
        :type: list[str]
        """

        self._storage_disk_ids = storage_disk_ids

    @property
    def vcpus(self):
        """Gets the vcpus of this CreateVMBody.  # noqa: E501


        :return: The vcpus of this CreateVMBody.  # noqa: E501
        :rtype: int
        """
        return self._vcpus

    @vcpus.setter
    def vcpus(self, vcpus):
        """Sets the vcpus of this CreateVMBody.


        :param vcpus: The vcpus of this CreateVMBody.  # noqa: E501
        :type: int
        """

        self._vcpus = vcpus

    @property
    def vm_id(self):
        """Gets the vm_id of this CreateVMBody.  # noqa: E501


        :return: The vm_id of this CreateVMBody.  # noqa: E501
        :rtype: str
        """
        return self._vm_id

    @vm_id.setter
    def vm_id(self, vm_id):
        """Sets the vm_id of this CreateVMBody.


        :param vm_id: The vm_id of this CreateVMBody.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and vm_id is None:
            raise ValueError("Invalid value for `vm_id`, must not be `None`")  # noqa: E501

        self._vm_id = vm_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateVMBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateVMBody):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateVMBody):
            return True

        return self.to_dict() != other.to_dict()



from cudo_compute import cudo_api
from cudo_compute.rest import ApiException

try:
    api = cudo_api.virtual_machines()
    api.terminate_vm(cudo_api.project_id(), 'my-vm-id')
except ApiException as e:
    print(e)



import cudo_compute as cudo
import os

home = os.path.expanduser("~")


def client():
    configuration = cudo.Configuration()
    key, err = get_api_key()

    if err:
        return None, err

    configuration.api_key['Authorization'] = key
    # configuration.debug = True
    configuration.api_key_prefix['Authorization'] = 'Bearer'
    configuration.host = "https://rest.compute.cudo.org"

    client = cudo.ApiClient(configuration)
    return client, None


def get_api_key():
    key_config, context_config, error = cudo.AuthConfig.load_config(home + '/.config/cudo/cudo.yml', "")
    if not error:
        return key_config['key'], None
    else:
        return None, error


def get_project_id():
    key_config, context_config, error = cudo.AuthConfig.load_config(home + '/.config/cudo/cudo.yml', "")
    if not error:
        return context_config['project'], None
    else:
        return None, error


def project_id():
    p, e = get_project_id()
    if e is None:
        return p
    return ''


# APIs
def api_keys():
    c, err = client()
    if err:
        raise Exception(err)
    return cudo.APIKeysApi(c)


def disks():
    c, err = client()
    if err:
        raise Exception(err)
    return cudo.DisksApi(c)


def networks():
    c, err = client()
    if err:
        raise Exception(err)
    return cudo.NetworksApi(c)


def object_storage():
    c, err = client()
    if err:
        raise Exception(err)
    return cudo.ObjectStorageApi(c)


def permissions():
    c, err = client()
    if err:
        raise Exception(err)
    return cudo.PermissionsApi(c)


def projects():
    c, err = client()
    if err:
        raise Exception(err)
    return cudo.ProjectsApi(c)


def ssh_keys():
    c, err = client()
    if err:
        raise Exception(err)
    return cudo.SSHKeysApi(c)


def search():
    c, err = client()
    if err:
        raise Exception(err)
    return cudo.SearchApi(c)


def user():
    c, err = client()
    if err:
        raise Exception(err)
    return cudo.UserApi(c)


def virtual_machines():
    c, err = client()
    if err:
        raise Exception(err)
    return cudo.VirtualMachinesApi(c)



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class Image(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'display_name': 'str',
        'id': 'str',
        'name': 'str',
        'platform': 'str',
        'size_gib': 'int'
    }

    attribute_map = {
        'description': 'description',
        'display_name': 'displayName',
        'id': 'id',
        'name': 'name',
        'platform': 'platform',
        'size_gib': 'sizeGib'
    }

    def __init__(self, description=None, display_name=None, id=None, name=None, platform=None, size_gib=None, _configuration=None):  # noqa: E501
        """Image - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._description = None
        self._display_name = None
        self._id = None
        self._name = None
        self._platform = None
        self._size_gib = None
        self.discriminator = None

        self.description = description
        self.display_name = display_name
        self.id = id
        self.name = name
        self.platform = platform
        self.size_gib = size_gib

    @property
    def description(self):
        """Gets the description of this Image.  # noqa: E501


        :return: The description of this Image.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Image.


        :param description: The description of this Image.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and description is None:
            raise ValueError("Invalid value for `description`, must not be `None`")  # noqa: E501

        self._description = description

    @property
    def display_name(self):
        """Gets the display_name of this Image.  # noqa: E501


        :return: The display_name of this Image.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this Image.


        :param display_name: The display_name of this Image.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and display_name is None:
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501

        self._display_name = display_name

    @property
    def id(self):
        """Gets the id of this Image.  # noqa: E501


        :return: The id of this Image.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Image.


        :param id: The id of this Image.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this Image.  # noqa: E501


        :return: The name of this Image.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Image.


        :param name: The name of this Image.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def platform(self):
        """Gets the platform of this Image.  # noqa: E501


        :return: The platform of this Image.  # noqa: E501
        :rtype: str
        """
        return self._platform

    @platform.setter
    def platform(self, platform):
        """Sets the platform of this Image.


        :param platform: The platform of this Image.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and platform is None:
            raise ValueError("Invalid value for `platform`, must not be `None`")  # noqa: E501

        self._platform = platform

    @property
    def size_gib(self):
        """Gets the size_gib of this Image.  # noqa: E501


        :return: The size_gib of this Image.  # noqa: E501
        :rtype: int
        """
        return self._size_gib

    @size_gib.setter
    def size_gib(self, size_gib):
        """Sets the size_gib of this Image.


        :param size_gib: The size_gib of this Image.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and size_gib is None:
            raise ValueError("Invalid value for `size_gib`, must not be `None`")  # noqa: E501

        self._size_gib = size_gib

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Image, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Image):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Image):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from cudo_compute.api.api_keys_api import APIKeysApi
from cudo_compute.api.billing_api import BillingApi
from cudo_compute.api.data_centers_api import DataCentersApi
from cudo_compute.api.disks_api import DisksApi
from cudo_compute.api.machine_types_api import MachineTypesApi
from cudo_compute.api.networks_api import NetworksApi
from cudo_compute.api.object_storage_api import ObjectStorageApi
from cudo_compute.api.permissions_api import PermissionsApi
from cudo_compute.api.projects_api import ProjectsApi
from cudo_compute.api.ssh_keys_api import SSHKeysApi
from cudo_compute.api.search_api import SearchApi
from cudo_compute.api.user_api import UserApi
from cudo_compute.api.virtual_machines_api import VirtualMachinesApi



import os
import fileinput


def replace_in_files(directory):
    file_extension = ".py"
    old_string = "auth_settings = []  # noqa: E501"
    new_string = "auth_settings = ['Authorization']"
    for root, dirs, files in os.walk(directory):
        for file in files:
            if file.endswith(file_extension):
                file_path = os.path.join(root, file)
                replace_in_file(file_path, old_string, new_string)


def replace_in_file(file_path, old_string, new_string):
    with fileinput.FileInput(file_path, inplace=True) as file:
        for line in file:
            print(line.replace(old_string, new_string), end='')


def replace_multiline_in_file(file_path, old_multiline, new_multiline):
    with open(file_path, 'r') as file:
        content = file.read()

    with open(file_path, 'w') as file:
        file.write(content.replace(old_multiline, new_multiline))


replace_in_files('src/cudo_compute')

with open('tools/func.txt', 'r') as replacement_file:
    new_func = replacement_file.read()

with open('tools/old_func.txt', 'r') as find_file:
    old_func = find_file.read()

replace_multiline_in_file('src/cudo_compute/configuration.py', old_func, new_func)



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class SecurityGroupRule(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'icmp_type': 'str',
        'id': 'str',
        'ip_range_cidr': 'str',
        'ports': 'str',
        'protocol': 'Protocol',
        'rule_type': 'RuleType'
    }

    attribute_map = {
        'icmp_type': 'icmpType',
        'id': 'id',
        'ip_range_cidr': 'ipRangeCidr',
        'ports': 'ports',
        'protocol': 'protocol',
        'rule_type': 'ruleType'
    }

    def __init__(self, icmp_type=None, id=None, ip_range_cidr=None, ports=None, protocol=None, rule_type=None, _configuration=None):  # noqa: E501
        """SecurityGroupRule - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._icmp_type = None
        self._id = None
        self._ip_range_cidr = None
        self._ports = None
        self._protocol = None
        self._rule_type = None
        self.discriminator = None

        if icmp_type is not None:
            self.icmp_type = icmp_type
        if id is not None:
            self.id = id
        if ip_range_cidr is not None:
            self.ip_range_cidr = ip_range_cidr
        if ports is not None:
            self.ports = ports
        if protocol is not None:
            self.protocol = protocol
        if rule_type is not None:
            self.rule_type = rule_type

    @property
    def icmp_type(self):
        """Gets the icmp_type of this SecurityGroupRule.  # noqa: E501


        :return: The icmp_type of this SecurityGroupRule.  # noqa: E501
        :rtype: str
        """
        return self._icmp_type

    @icmp_type.setter
    def icmp_type(self, icmp_type):
        """Sets the icmp_type of this SecurityGroupRule.


        :param icmp_type: The icmp_type of this SecurityGroupRule.  # noqa: E501
        :type: str
        """

        self._icmp_type = icmp_type

    @property
    def id(self):
        """Gets the id of this SecurityGroupRule.  # noqa: E501


        :return: The id of this SecurityGroupRule.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SecurityGroupRule.


        :param id: The id of this SecurityGroupRule.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def ip_range_cidr(self):
        """Gets the ip_range_cidr of this SecurityGroupRule.  # noqa: E501


        :return: The ip_range_cidr of this SecurityGroupRule.  # noqa: E501
        :rtype: str
        """
        return self._ip_range_cidr

    @ip_range_cidr.setter
    def ip_range_cidr(self, ip_range_cidr):
        """Sets the ip_range_cidr of this SecurityGroupRule.


        :param ip_range_cidr: The ip_range_cidr of this SecurityGroupRule.  # noqa: E501
        :type: str
        """

        self._ip_range_cidr = ip_range_cidr

    @property
    def ports(self):
        """Gets the ports of this SecurityGroupRule.  # noqa: E501


        :return: The ports of this SecurityGroupRule.  # noqa: E501
        :rtype: str
        """
        return self._ports

    @ports.setter
    def ports(self, ports):
        """Sets the ports of this SecurityGroupRule.


        :param ports: The ports of this SecurityGroupRule.  # noqa: E501
        :type: str
        """

        self._ports = ports

    @property
    def protocol(self):
        """Gets the protocol of this SecurityGroupRule.  # noqa: E501


        :return: The protocol of this SecurityGroupRule.  # noqa: E501
        :rtype: Protocol
        """
        return self._protocol

    @protocol.setter
    def protocol(self, protocol):
        """Sets the protocol of this SecurityGroupRule.


        :param protocol: The protocol of this SecurityGroupRule.  # noqa: E501
        :type: Protocol
        """

        self._protocol = protocol

    @property
    def rule_type(self):
        """Gets the rule_type of this SecurityGroupRule.  # noqa: E501


        :return: The rule_type of this SecurityGroupRule.  # noqa: E501
        :rtype: RuleType
        """
        return self._rule_type

    @rule_type.setter
    def rule_type(self, rule_type):
        """Sets the rule_type of this SecurityGroupRule.


        :param rule_type: The rule_type of this SecurityGroupRule.  # noqa: E501
        :type: RuleType
        """

        self._rule_type = rule_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SecurityGroupRule, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SecurityGroupRule):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SecurityGroupRule):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import cudo_compute
from cudo_compute.api.user_api import UserApi  # noqa: E501
from cudo_compute.rest import ApiException


class TestUserApi(unittest.TestCase):
    """UserApi unit test stubs"""

    def setUp(self):
        self.api = cudo_compute.api.user_api.UserApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_identity_verification_session(self):
        """Test case for create_identity_verification_session

        Get identity verification session  # noqa: E501
        """
        pass

    def test_delete_user(self):
        """Test case for delete_user

        Delete  # noqa: E501
        """
        pass

    def test_get(self):
        """Test case for get

        Get  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from cudo_compute.configuration import Configuration


class Decimal(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'value': 'str'
    }

    attribute_map = {
        'value': 'value'
    }

    def __init__(self, value=None, _configuration=None):  # noqa: E501
        """Decimal - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._value = None
        self.discriminator = None

        if value is not None:
            self.value = value

    @property
    def value(self):
        """Gets the value of this Decimal.  # noqa: E501

        The decimal value, as a string.  The string representation consists of an optional sign, `+` (`U+002B`) or `-` (`U+002D`), followed by a sequence of zero or more decimal digits (\"the integer\"), optionally followed by a fraction, optionally followed by an exponent.  The fraction consists of a decimal point followed by zero or more decimal digits. The string must contain at least one digit in either the integer or the fraction. The number formed by the sign, the integer and the fraction is referred to as the significand.  The exponent consists of the character `e` (`U+0065`) or `E` (`U+0045`) followed by one or more decimal digits.  Services **should** normalize decimal values before storing them by:    - Removing an explicitly-provided `+` sign (`+2.5` -> `2.5`).   - Replacing a zero-length integer value with `0` (`.5` -> `0.5`).   - Coercing the exponent character to lower-case (`2.5E8` -> `2.5e8`).   - Removing an explicitly-provided zero exponent (`2.5e0` -> `2.5`).  Services **may** perform additional normalization based on its own needs and the internal decimal implementation selected, such as shifting the decimal point and exponent value together (example: `2.5e-1` <-> `0.25`). Additionally, services **may** preserve trailing zeroes in the fraction to indicate increased precision, but are not required to do so.  Note that only the `.` character is supported to divide the integer and the fraction; `,` **should not** be supported regardless of locale. Additionally, thousand separators **should not** be supported. If a service does support them, values **must** be normalized.  The ENBF grammar is:      DecimalString =       [Sign] Significand [Exponent];      Sign = '+' | '-';      Significand =       Digits ['.'] [Digits] | [Digits] '.' Digits;      Exponent = ('e' | 'E') [Sign] Digits;      Digits = { '0' | '1' | '2' | '3' | '4' | '5' | '6' | '7' | '8' | '9' };  Services **should** clearly document the range of supported values, the maximum supported precision (total number of digits), and, if applicable, the scale (number of digits after the decimal point), as well as how it behaves when receiving out-of-bounds values.  Services **may** choose to accept values passed as input even when the value has a higher precision or scale than the service supports, and **should** round the value to fit the supported scale. Alternatively, the service **may** error with `400 Bad Request` (`INVALID_ARGUMENT` in gRPC) if precision would be lost.  Services **should** error with `400 Bad Request` (`INVALID_ARGUMENT` in gRPC) if the service receives a value outside of the supported range.  # noqa: E501

        :return: The value of this Decimal.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this Decimal.

        The decimal value, as a string.  The string representation consists of an optional sign, `+` (`U+002B`) or `-` (`U+002D`), followed by a sequence of zero or more decimal digits (\"the integer\"), optionally followed by a fraction, optionally followed by an exponent.  The fraction consists of a decimal point followed by zero or more decimal digits. The string must contain at least one digit in either the integer or the fraction. The number formed by the sign, the integer and the fraction is referred to as the significand.  The exponent consists of the character `e` (`U+0065`) or `E` (`U+0045`) followed by one or more decimal digits.  Services **should** normalize decimal values before storing them by:    - Removing an explicitly-provided `+` sign (`+2.5` -> `2.5`).   - Replacing a zero-length integer value with `0` (`.5` -> `0.5`).   - Coercing the exponent character to lower-case (`2.5E8` -> `2.5e8`).   - Removing an explicitly-provided zero exponent (`2.5e0` -> `2.5`).  Services **may** perform additional normalization based on its own needs and the internal decimal implementation selected, such as shifting the decimal point and exponent value together (example: `2.5e-1` <-> `0.25`). Additionally, services **may** preserve trailing zeroes in the fraction to indicate increased precision, but are not required to do so.  Note that only the `.` character is supported to divide the integer and the fraction; `,` **should not** be supported regardless of locale. Additionally, thousand separators **should not** be supported. If a service does support them, values **must** be normalized.  The ENBF grammar is:      DecimalString =       [Sign] Significand [Exponent];      Sign = '+' | '-';      Significand =       Digits ['.'] [Digits] | [Digits] '.' Digits;      Exponent = ('e' | 'E') [Sign] Digits;      Digits = { '0' | '1' | '2' | '3' | '4' | '5' | '6' | '7' | '8' | '9' };  Services **should** clearly document the range of supported values, the maximum supported precision (total number of digits), and, if applicable, the scale (number of digits after the decimal point), as well as how it behaves when receiving out-of-bounds values.  Services **may** choose to accept values passed as input even when the value has a higher precision or scale than the service supports, and **should** round the value to fit the supported scale. Alternatively, the service **may** error with `400 Bad Request` (`INVALID_ARGUMENT` in gRPC) if precision would be lost.  Services **should** error with `400 Bad Request` (`INVALID_ARGUMENT` in gRPC) if the service receives a value outside of the supported range.  # noqa: E501

        :param value: The value of this Decimal.  # noqa: E501
        :type: str
        """

        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Decimal, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Decimal):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Decimal):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from src.cudo_compute.configuration import Configuration


class Invoice(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'amount_due': 'str',
        'amount_paid': 'str',
        'amount_remaining': 'str',
        'auto_advance': 'bool',
        'billing_reason': 'str',
        'created': 'str',
        'currency': 'str',
        'description': 'str',
        'due_date': 'str',
        'hosted_invoice_url': 'str',
        'id': 'str',
        'number': 'str',
        'paid_date': 'str',
        'period_end': 'str',
        'period_start': 'str',
        'status': 'str'
    }

    attribute_map = {
        'amount_due': 'amountDue',
        'amount_paid': 'amountPaid',
        'amount_remaining': 'amountRemaining',
        'auto_advance': 'autoAdvance',
        'billing_reason': 'billingReason',
        'created': 'created',
        'currency': 'currency',
        'description': 'description',
        'due_date': 'dueDate',
        'hosted_invoice_url': 'hostedInvoiceUrl',
        'id': 'id',
        'number': 'number',
        'paid_date': 'paidDate',
        'period_end': 'periodEnd',
        'period_start': 'periodStart',
        'status': 'status'
    }

    def __init__(self, amount_due=None, amount_paid=None, amount_remaining=None, auto_advance=None, billing_reason=None, created=None, currency=None, description=None, due_date=None, hosted_invoice_url=None, id=None, number=None, paid_date=None, period_end=None, period_start=None, status=None, _configuration=None):  # noqa: E501
        """Invoice - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._amount_due = None
        self._amount_paid = None
        self._amount_remaining = None
        self._auto_advance = None
        self._billing_reason = None
        self._created = None
        self._currency = None
        self._description = None
        self._due_date = None
        self._hosted_invoice_url = None
        self._id = None
        self._number = None
        self._paid_date = None
        self._period_end = None
        self._period_start = None
        self._status = None
        self.discriminator = None

        if amount_due is not None:
            self.amount_due = amount_due
        if amount_paid is not None:
            self.amount_paid = amount_paid
        if amount_remaining is not None:
            self.amount_remaining = amount_remaining
        if auto_advance is not None:
            self.auto_advance = auto_advance
        if billing_reason is not None:
            self.billing_reason = billing_reason
        if created is not None:
            self.created = created
        if currency is not None:
            self.currency = currency
        if description is not None:
            self.description = description
        if due_date is not None:
            self.due_date = due_date
        if hosted_invoice_url is not None:
            self.hosted_invoice_url = hosted_invoice_url
        if id is not None:
            self.id = id
        if number is not None:
            self.number = number
        if paid_date is not None:
            self.paid_date = paid_date
        if period_end is not None:
            self.period_end = period_end
        if period_start is not None:
            self.period_start = period_start
        if status is not None:
            self.status = status

    @property
    def amount_due(self):
        """Gets the amount_due of this Invoice.  # noqa: E501


        :return: The amount_due of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._amount_due

    @amount_due.setter
    def amount_due(self, amount_due):
        """Sets the amount_due of this Invoice.


        :param amount_due: The amount_due of this Invoice.  # noqa: E501
        :type: str
        """

        self._amount_due = amount_due

    @property
    def amount_paid(self):
        """Gets the amount_paid of this Invoice.  # noqa: E501


        :return: The amount_paid of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._amount_paid

    @amount_paid.setter
    def amount_paid(self, amount_paid):
        """Sets the amount_paid of this Invoice.


        :param amount_paid: The amount_paid of this Invoice.  # noqa: E501
        :type: str
        """

        self._amount_paid = amount_paid

    @property
    def amount_remaining(self):
        """Gets the amount_remaining of this Invoice.  # noqa: E501


        :return: The amount_remaining of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._amount_remaining

    @amount_remaining.setter
    def amount_remaining(self, amount_remaining):
        """Sets the amount_remaining of this Invoice.


        :param amount_remaining: The amount_remaining of this Invoice.  # noqa: E501
        :type: str
        """

        self._amount_remaining = amount_remaining

    @property
    def auto_advance(self):
        """Gets the auto_advance of this Invoice.  # noqa: E501


        :return: The auto_advance of this Invoice.  # noqa: E501
        :rtype: bool
        """
        return self._auto_advance

    @auto_advance.setter
    def auto_advance(self, auto_advance):
        """Sets the auto_advance of this Invoice.


        :param auto_advance: The auto_advance of this Invoice.  # noqa: E501
        :type: bool
        """

        self._auto_advance = auto_advance

    @property
    def billing_reason(self):
        """Gets the billing_reason of this Invoice.  # noqa: E501


        :return: The billing_reason of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._billing_reason

    @billing_reason.setter
    def billing_reason(self, billing_reason):
        """Sets the billing_reason of this Invoice.


        :param billing_reason: The billing_reason of this Invoice.  # noqa: E501
        :type: str
        """

        self._billing_reason = billing_reason

    @property
    def created(self):
        """Gets the created of this Invoice.  # noqa: E501


        :return: The created of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._created

    @created.setter
    def created(self, created):
        """Sets the created of this Invoice.


        :param created: The created of this Invoice.  # noqa: E501
        :type: str
        """

        self._created = created

    @property
    def currency(self):
        """Gets the currency of this Invoice.  # noqa: E501


        :return: The currency of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Invoice.


        :param currency: The currency of this Invoice.  # noqa: E501
        :type: str
        """

        self._currency = currency

    @property
    def description(self):
        """Gets the description of this Invoice.  # noqa: E501


        :return: The description of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this Invoice.


        :param description: The description of this Invoice.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def due_date(self):
        """Gets the due_date of this Invoice.  # noqa: E501


        :return: The due_date of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this Invoice.


        :param due_date: The due_date of this Invoice.  # noqa: E501
        :type: str
        """

        self._due_date = due_date

    @property
    def hosted_invoice_url(self):
        """Gets the hosted_invoice_url of this Invoice.  # noqa: E501


        :return: The hosted_invoice_url of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._hosted_invoice_url

    @hosted_invoice_url.setter
    def hosted_invoice_url(self, hosted_invoice_url):
        """Sets the hosted_invoice_url of this Invoice.


        :param hosted_invoice_url: The hosted_invoice_url of this Invoice.  # noqa: E501
        :type: str
        """

        self._hosted_invoice_url = hosted_invoice_url

    @property
    def id(self):
        """Gets the id of this Invoice.  # noqa: E501


        :return: The id of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Invoice.


        :param id: The id of this Invoice.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def number(self):
        """Gets the number of this Invoice.  # noqa: E501


        :return: The number of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._number

    @number.setter
    def number(self, number):
        """Sets the number of this Invoice.


        :param number: The number of this Invoice.  # noqa: E501
        :type: str
        """

        self._number = number

    @property
    def paid_date(self):
        """Gets the paid_date of this Invoice.  # noqa: E501


        :return: The paid_date of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._paid_date

    @paid_date.setter
    def paid_date(self, paid_date):
        """Sets the paid_date of this Invoice.


        :param paid_date: The paid_date of this Invoice.  # noqa: E501
        :type: str
        """

        self._paid_date = paid_date

    @property
    def period_end(self):
        """Gets the period_end of this Invoice.  # noqa: E501


        :return: The period_end of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._period_end

    @period_end.setter
    def period_end(self, period_end):
        """Sets the period_end of this Invoice.


        :param period_end: The period_end of this Invoice.  # noqa: E501
        :type: str
        """

        self._period_end = period_end

    @property
    def period_start(self):
        """Gets the period_start of this Invoice.  # noqa: E501


        :return: The period_start of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._period_start

    @period_start.setter
    def period_start(self, period_start):
        """Sets the period_start of this Invoice.


        :param period_start: The period_start of this Invoice.  # noqa: E501
        :type: str
        """

        self._period_start = period_start

    @property
    def status(self):
        """Gets the status of this Invoice.  # noqa: E501


        :return: The status of this Invoice.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Invoice.


        :param status: The status of this Invoice.  # noqa: E501
        :type: str
        """

        self._status = status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Invoice, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Invoice):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Invoice):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from src.cudo_compute.configuration import Configuration


class Cluster(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cpu_model': 'str',
        'create_time': 'datetime',
        'gpu_free': 'int',
        'gpu_model': 'str',
        'gpu_model_pci_types': 'list[str]',
        'gpu_price_hr': 'Decimal',
        'gpu_used': 'int',
        'host_count': 'int',
        'host_problem_count': 'int',
        'machine_type': 'str',
        'max_vcpu_per_gpu': 'float',
        'max_vcpu_per_memory_gib': 'float',
        'memory_gib_free': 'int',
        'memory_gib_price_hr': 'Decimal',
        'memory_gib_used': 'int',
        'min_vcpu_per_gpu': 'float',
        'min_vcpu_per_memory_gib': 'float',
        'update_time': 'datetime',
        'vcpu_free': 'int',
        'vcpu_per_cpu_thread': 'int',
        'vcpu_price_hr': 'Decimal',
        'vcpu_used': 'int',
        'vm_count': 'int'
    }

    attribute_map = {
        'cpu_model': 'cpuModel',
        'create_time': 'createTime',
        'gpu_free': 'gpuFree',
        'gpu_model': 'gpuModel',
        'gpu_model_pci_types': 'gpuModelPciTypes',
        'gpu_price_hr': 'gpuPriceHr',
        'gpu_used': 'gpuUsed',
        'host_count': 'hostCount',
        'host_problem_count': 'hostProblemCount',
        'machine_type': 'machineType',
        'max_vcpu_per_gpu': 'maxVcpuPerGpu',
        'max_vcpu_per_memory_gib': 'maxVcpuPerMemoryGib',
        'memory_gib_free': 'memoryGibFree',
        'memory_gib_price_hr': 'memoryGibPriceHr',
        'memory_gib_used': 'memoryGibUsed',
        'min_vcpu_per_gpu': 'minVcpuPerGpu',
        'min_vcpu_per_memory_gib': 'minVcpuPerMemoryGib',
        'update_time': 'updateTime',
        'vcpu_free': 'vcpuFree',
        'vcpu_per_cpu_thread': 'vcpuPerCpuThread',
        'vcpu_price_hr': 'vcpuPriceHr',
        'vcpu_used': 'vcpuUsed',
        'vm_count': 'vmCount'
    }

    def __init__(self, cpu_model=None, create_time=None, gpu_free=None, gpu_model=None, gpu_model_pci_types=None, gpu_price_hr=None, gpu_used=None, host_count=None, host_problem_count=None, machine_type=None, max_vcpu_per_gpu=None, max_vcpu_per_memory_gib=None, memory_gib_free=None, memory_gib_price_hr=None, memory_gib_used=None, min_vcpu_per_gpu=None, min_vcpu_per_memory_gib=None, update_time=None, vcpu_free=None, vcpu_per_cpu_thread=None, vcpu_price_hr=None, vcpu_used=None, vm_count=None, _configuration=None):  # noqa: E501
        """Cluster - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cpu_model = None
        self._create_time = None
        self._gpu_free = None
        self._gpu_model = None
        self._gpu_model_pci_types = None
        self._gpu_price_hr = None
        self._gpu_used = None
        self._host_count = None
        self._host_problem_count = None
        self._machine_type = None
        self._max_vcpu_per_gpu = None
        self._max_vcpu_per_memory_gib = None
        self._memory_gib_free = None
        self._memory_gib_price_hr = None
        self._memory_gib_used = None
        self._min_vcpu_per_gpu = None
        self._min_vcpu_per_memory_gib = None
        self._update_time = None
        self._vcpu_free = None
        self._vcpu_per_cpu_thread = None
        self._vcpu_price_hr = None
        self._vcpu_used = None
        self._vm_count = None
        self.discriminator = None

        self.cpu_model = cpu_model
        self.create_time = create_time
        self.gpu_free = gpu_free
        self.gpu_model = gpu_model
        self.gpu_model_pci_types = gpu_model_pci_types
        self.gpu_price_hr = gpu_price_hr
        self.gpu_used = gpu_used
        self.host_count = host_count
        self.host_problem_count = host_problem_count
        self.machine_type = machine_type
        self.max_vcpu_per_gpu = max_vcpu_per_gpu
        self.max_vcpu_per_memory_gib = max_vcpu_per_memory_gib
        self.memory_gib_free = memory_gib_free
        self.memory_gib_price_hr = memory_gib_price_hr
        self.memory_gib_used = memory_gib_used
        self.min_vcpu_per_gpu = min_vcpu_per_gpu
        self.min_vcpu_per_memory_gib = min_vcpu_per_memory_gib
        self.update_time = update_time
        self.vcpu_free = vcpu_free
        self.vcpu_per_cpu_thread = vcpu_per_cpu_thread
        self.vcpu_price_hr = vcpu_price_hr
        self.vcpu_used = vcpu_used
        self.vm_count = vm_count

    @property
    def cpu_model(self):
        """Gets the cpu_model of this Cluster.  # noqa: E501


        :return: The cpu_model of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._cpu_model

    @cpu_model.setter
    def cpu_model(self, cpu_model):
        """Sets the cpu_model of this Cluster.


        :param cpu_model: The cpu_model of this Cluster.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and cpu_model is None:
            raise ValueError("Invalid value for `cpu_model`, must not be `None`")  # noqa: E501

        self._cpu_model = cpu_model

    @property
    def create_time(self):
        """Gets the create_time of this Cluster.  # noqa: E501


        :return: The create_time of this Cluster.  # noqa: E501
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this Cluster.


        :param create_time: The create_time of this Cluster.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and create_time is None:
            raise ValueError("Invalid value for `create_time`, must not be `None`")  # noqa: E501

        self._create_time = create_time

    @property
    def gpu_free(self):
        """Gets the gpu_free of this Cluster.  # noqa: E501


        :return: The gpu_free of this Cluster.  # noqa: E501
        :rtype: int
        """
        return self._gpu_free

    @gpu_free.setter
    def gpu_free(self, gpu_free):
        """Sets the gpu_free of this Cluster.


        :param gpu_free: The gpu_free of this Cluster.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and gpu_free is None:
            raise ValueError("Invalid value for `gpu_free`, must not be `None`")  # noqa: E501

        self._gpu_free = gpu_free

    @property
    def gpu_model(self):
        """Gets the gpu_model of this Cluster.  # noqa: E501


        :return: The gpu_model of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._gpu_model

    @gpu_model.setter
    def gpu_model(self, gpu_model):
        """Sets the gpu_model of this Cluster.


        :param gpu_model: The gpu_model of this Cluster.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and gpu_model is None:
            raise ValueError("Invalid value for `gpu_model`, must not be `None`")  # noqa: E501

        self._gpu_model = gpu_model

    @property
    def gpu_model_pci_types(self):
        """Gets the gpu_model_pci_types of this Cluster.  # noqa: E501


        :return: The gpu_model_pci_types of this Cluster.  # noqa: E501
        :rtype: list[str]
        """
        return self._gpu_model_pci_types

    @gpu_model_pci_types.setter
    def gpu_model_pci_types(self, gpu_model_pci_types):
        """Sets the gpu_model_pci_types of this Cluster.


        :param gpu_model_pci_types: The gpu_model_pci_types of this Cluster.  # noqa: E501
        :type: list[str]
        """
        if self._configuration.client_side_validation and gpu_model_pci_types is None:
            raise ValueError("Invalid value for `gpu_model_pci_types`, must not be `None`")  # noqa: E501

        self._gpu_model_pci_types = gpu_model_pci_types

    @property
    def gpu_price_hr(self):
        """Gets the gpu_price_hr of this Cluster.  # noqa: E501


        :return: The gpu_price_hr of this Cluster.  # noqa: E501
        :rtype: Decimal
        """
        return self._gpu_price_hr

    @gpu_price_hr.setter
    def gpu_price_hr(self, gpu_price_hr):
        """Sets the gpu_price_hr of this Cluster.


        :param gpu_price_hr: The gpu_price_hr of this Cluster.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and gpu_price_hr is None:
            raise ValueError("Invalid value for `gpu_price_hr`, must not be `None`")  # noqa: E501

        self._gpu_price_hr = gpu_price_hr

    @property
    def gpu_used(self):
        """Gets the gpu_used of this Cluster.  # noqa: E501


        :return: The gpu_used of this Cluster.  # noqa: E501
        :rtype: int
        """
        return self._gpu_used

    @gpu_used.setter
    def gpu_used(self, gpu_used):
        """Sets the gpu_used of this Cluster.


        :param gpu_used: The gpu_used of this Cluster.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and gpu_used is None:
            raise ValueError("Invalid value for `gpu_used`, must not be `None`")  # noqa: E501

        self._gpu_used = gpu_used

    @property
    def host_count(self):
        """Gets the host_count of this Cluster.  # noqa: E501


        :return: The host_count of this Cluster.  # noqa: E501
        :rtype: int
        """
        return self._host_count

    @host_count.setter
    def host_count(self, host_count):
        """Sets the host_count of this Cluster.


        :param host_count: The host_count of this Cluster.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and host_count is None:
            raise ValueError("Invalid value for `host_count`, must not be `None`")  # noqa: E501

        self._host_count = host_count

    @property
    def host_problem_count(self):
        """Gets the host_problem_count of this Cluster.  # noqa: E501


        :return: The host_problem_count of this Cluster.  # noqa: E501
        :rtype: int
        """
        return self._host_problem_count

    @host_problem_count.setter
    def host_problem_count(self, host_problem_count):
        """Sets the host_problem_count of this Cluster.


        :param host_problem_count: The host_problem_count of this Cluster.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and host_problem_count is None:
            raise ValueError("Invalid value for `host_problem_count`, must not be `None`")  # noqa: E501

        self._host_problem_count = host_problem_count

    @property
    def machine_type(self):
        """Gets the machine_type of this Cluster.  # noqa: E501


        :return: The machine_type of this Cluster.  # noqa: E501
        :rtype: str
        """
        return self._machine_type

    @machine_type.setter
    def machine_type(self, machine_type):
        """Sets the machine_type of this Cluster.


        :param machine_type: The machine_type of this Cluster.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and machine_type is None:
            raise ValueError("Invalid value for `machine_type`, must not be `None`")  # noqa: E501

        self._machine_type = machine_type

    @property
    def max_vcpu_per_gpu(self):
        """Gets the max_vcpu_per_gpu of this Cluster.  # noqa: E501


        :return: The max_vcpu_per_gpu of this Cluster.  # noqa: E501
        :rtype: float
        """
        return self._max_vcpu_per_gpu

    @max_vcpu_per_gpu.setter
    def max_vcpu_per_gpu(self, max_vcpu_per_gpu):
        """Sets the max_vcpu_per_gpu of this Cluster.


        :param max_vcpu_per_gpu: The max_vcpu_per_gpu of this Cluster.  # noqa: E501
        :type: float
        """
        if self._configuration.client_side_validation and max_vcpu_per_gpu is None:
            raise ValueError("Invalid value for `max_vcpu_per_gpu`, must not be `None`")  # noqa: E501

        self._max_vcpu_per_gpu = max_vcpu_per_gpu

    @property
    def max_vcpu_per_memory_gib(self):
        """Gets the max_vcpu_per_memory_gib of this Cluster.  # noqa: E501


        :return: The max_vcpu_per_memory_gib of this Cluster.  # noqa: E501
        :rtype: float
        """
        return self._max_vcpu_per_memory_gib

    @max_vcpu_per_memory_gib.setter
    def max_vcpu_per_memory_gib(self, max_vcpu_per_memory_gib):
        """Sets the max_vcpu_per_memory_gib of this Cluster.


        :param max_vcpu_per_memory_gib: The max_vcpu_per_memory_gib of this Cluster.  # noqa: E501
        :type: float
        """
        if self._configuration.client_side_validation and max_vcpu_per_memory_gib is None:
            raise ValueError("Invalid value for `max_vcpu_per_memory_gib`, must not be `None`")  # noqa: E501

        self._max_vcpu_per_memory_gib = max_vcpu_per_memory_gib

    @property
    def memory_gib_free(self):
        """Gets the memory_gib_free of this Cluster.  # noqa: E501


        :return: The memory_gib_free of this Cluster.  # noqa: E501
        :rtype: int
        """
        return self._memory_gib_free

    @memory_gib_free.setter
    def memory_gib_free(self, memory_gib_free):
        """Sets the memory_gib_free of this Cluster.


        :param memory_gib_free: The memory_gib_free of this Cluster.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and memory_gib_free is None:
            raise ValueError("Invalid value for `memory_gib_free`, must not be `None`")  # noqa: E501

        self._memory_gib_free = memory_gib_free

    @property
    def memory_gib_price_hr(self):
        """Gets the memory_gib_price_hr of this Cluster.  # noqa: E501


        :return: The memory_gib_price_hr of this Cluster.  # noqa: E501
        :rtype: Decimal
        """
        return self._memory_gib_price_hr

    @memory_gib_price_hr.setter
    def memory_gib_price_hr(self, memory_gib_price_hr):
        """Sets the memory_gib_price_hr of this Cluster.


        :param memory_gib_price_hr: The memory_gib_price_hr of this Cluster.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and memory_gib_price_hr is None:
            raise ValueError("Invalid value for `memory_gib_price_hr`, must not be `None`")  # noqa: E501

        self._memory_gib_price_hr = memory_gib_price_hr

    @property
    def memory_gib_used(self):
        """Gets the memory_gib_used of this Cluster.  # noqa: E501


        :return: The memory_gib_used of this Cluster.  # noqa: E501
        :rtype: int
        """
        return self._memory_gib_used

    @memory_gib_used.setter
    def memory_gib_used(self, memory_gib_used):
        """Sets the memory_gib_used of this Cluster.


        :param memory_gib_used: The memory_gib_used of this Cluster.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and memory_gib_used is None:
            raise ValueError("Invalid value for `memory_gib_used`, must not be `None`")  # noqa: E501

        self._memory_gib_used = memory_gib_used

    @property
    def min_vcpu_per_gpu(self):
        """Gets the min_vcpu_per_gpu of this Cluster.  # noqa: E501


        :return: The min_vcpu_per_gpu of this Cluster.  # noqa: E501
        :rtype: float
        """
        return self._min_vcpu_per_gpu

    @min_vcpu_per_gpu.setter
    def min_vcpu_per_gpu(self, min_vcpu_per_gpu):
        """Sets the min_vcpu_per_gpu of this Cluster.


        :param min_vcpu_per_gpu: The min_vcpu_per_gpu of this Cluster.  # noqa: E501
        :type: float
        """
        if self._configuration.client_side_validation and min_vcpu_per_gpu is None:
            raise ValueError("Invalid value for `min_vcpu_per_gpu`, must not be `None`")  # noqa: E501

        self._min_vcpu_per_gpu = min_vcpu_per_gpu

    @property
    def min_vcpu_per_memory_gib(self):
        """Gets the min_vcpu_per_memory_gib of this Cluster.  # noqa: E501


        :return: The min_vcpu_per_memory_gib of this Cluster.  # noqa: E501
        :rtype: float
        """
        return self._min_vcpu_per_memory_gib

    @min_vcpu_per_memory_gib.setter
    def min_vcpu_per_memory_gib(self, min_vcpu_per_memory_gib):
        """Sets the min_vcpu_per_memory_gib of this Cluster.


        :param min_vcpu_per_memory_gib: The min_vcpu_per_memory_gib of this Cluster.  # noqa: E501
        :type: float
        """
        if self._configuration.client_side_validation and min_vcpu_per_memory_gib is None:
            raise ValueError("Invalid value for `min_vcpu_per_memory_gib`, must not be `None`")  # noqa: E501

        self._min_vcpu_per_memory_gib = min_vcpu_per_memory_gib

    @property
    def update_time(self):
        """Gets the update_time of this Cluster.  # noqa: E501


        :return: The update_time of this Cluster.  # noqa: E501
        :rtype: datetime
        """
        return self._update_time

    @update_time.setter
    def update_time(self, update_time):
        """Sets the update_time of this Cluster.


        :param update_time: The update_time of this Cluster.  # noqa: E501
        :type: datetime
        """
        if self._configuration.client_side_validation and update_time is None:
            raise ValueError("Invalid value for `update_time`, must not be `None`")  # noqa: E501

        self._update_time = update_time

    @property
    def vcpu_free(self):
        """Gets the vcpu_free of this Cluster.  # noqa: E501


        :return: The vcpu_free of this Cluster.  # noqa: E501
        :rtype: int
        """
        return self._vcpu_free

    @vcpu_free.setter
    def vcpu_free(self, vcpu_free):
        """Sets the vcpu_free of this Cluster.


        :param vcpu_free: The vcpu_free of this Cluster.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and vcpu_free is None:
            raise ValueError("Invalid value for `vcpu_free`, must not be `None`")  # noqa: E501

        self._vcpu_free = vcpu_free

    @property
    def vcpu_per_cpu_thread(self):
        """Gets the vcpu_per_cpu_thread of this Cluster.  # noqa: E501


        :return: The vcpu_per_cpu_thread of this Cluster.  # noqa: E501
        :rtype: int
        """
        return self._vcpu_per_cpu_thread

    @vcpu_per_cpu_thread.setter
    def vcpu_per_cpu_thread(self, vcpu_per_cpu_thread):
        """Sets the vcpu_per_cpu_thread of this Cluster.


        :param vcpu_per_cpu_thread: The vcpu_per_cpu_thread of this Cluster.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and vcpu_per_cpu_thread is None:
            raise ValueError("Invalid value for `vcpu_per_cpu_thread`, must not be `None`")  # noqa: E501

        self._vcpu_per_cpu_thread = vcpu_per_cpu_thread

    @property
    def vcpu_price_hr(self):
        """Gets the vcpu_price_hr of this Cluster.  # noqa: E501


        :return: The vcpu_price_hr of this Cluster.  # noqa: E501
        :rtype: Decimal
        """
        return self._vcpu_price_hr

    @vcpu_price_hr.setter
    def vcpu_price_hr(self, vcpu_price_hr):
        """Sets the vcpu_price_hr of this Cluster.


        :param vcpu_price_hr: The vcpu_price_hr of this Cluster.  # noqa: E501
        :type: Decimal
        """
        if self._configuration.client_side_validation and vcpu_price_hr is None:
            raise ValueError("Invalid value for `vcpu_price_hr`, must not be `None`")  # noqa: E501

        self._vcpu_price_hr = vcpu_price_hr

    @property
    def vcpu_used(self):
        """Gets the vcpu_used of this Cluster.  # noqa: E501


        :return: The vcpu_used of this Cluster.  # noqa: E501
        :rtype: int
        """
        return self._vcpu_used

    @vcpu_used.setter
    def vcpu_used(self, vcpu_used):
        """Sets the vcpu_used of this Cluster.


        :param vcpu_used: The vcpu_used of this Cluster.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and vcpu_used is None:
            raise ValueError("Invalid value for `vcpu_used`, must not be `None`")  # noqa: E501

        self._vcpu_used = vcpu_used

    @property
    def vm_count(self):
        """Gets the vm_count of this Cluster.  # noqa: E501


        :return: The vm_count of this Cluster.  # noqa: E501
        :rtype: int
        """
        return self._vm_count

    @vm_count.setter
    def vm_count(self, vm_count):
        """Sets the vm_count of this Cluster.


        :param vm_count: The vm_count of this Cluster.  # noqa: E501
        :type: int
        """
        if self._configuration.client_side_validation and vm_count is None:
            raise ValueError("Invalid value for `vm_count`, must not be `None`")  # noqa: E501

        self._vm_count = vm_count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Cluster, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Cluster):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Cluster):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from src.cudo_compute.configuration import Configuration


class CreateNetworkBody(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'cidr_prefix': 'str',
        'data_center_id': 'str',
        'id': 'str',
        'network_id': 'str',
        'vrouter_size': 'VRouterSize'
    }

    attribute_map = {
        'cidr_prefix': 'cidrPrefix',
        'data_center_id': 'dataCenterId',
        'id': 'id',
        'network_id': 'networkId',
        'vrouter_size': 'vrouterSize'
    }

    def __init__(self, cidr_prefix=None, data_center_id=None, id=None, network_id=None, vrouter_size=None, _configuration=None):  # noqa: E501
        """CreateNetworkBody - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._cidr_prefix = None
        self._data_center_id = None
        self._id = None
        self._network_id = None
        self._vrouter_size = None
        self.discriminator = None

        self.cidr_prefix = cidr_prefix
        self.data_center_id = data_center_id
        self.id = id
        self.network_id = network_id
        if vrouter_size is not None:
            self.vrouter_size = vrouter_size

    @property
    def cidr_prefix(self):
        """Gets the cidr_prefix of this CreateNetworkBody.  # noqa: E501


        :return: The cidr_prefix of this CreateNetworkBody.  # noqa: E501
        :rtype: str
        """
        return self._cidr_prefix

    @cidr_prefix.setter
    def cidr_prefix(self, cidr_prefix):
        """Sets the cidr_prefix of this CreateNetworkBody.


        :param cidr_prefix: The cidr_prefix of this CreateNetworkBody.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and cidr_prefix is None:
            raise ValueError("Invalid value for `cidr_prefix`, must not be `None`")  # noqa: E501

        self._cidr_prefix = cidr_prefix

    @property
    def data_center_id(self):
        """Gets the data_center_id of this CreateNetworkBody.  # noqa: E501


        :return: The data_center_id of this CreateNetworkBody.  # noqa: E501
        :rtype: str
        """
        return self._data_center_id

    @data_center_id.setter
    def data_center_id(self, data_center_id):
        """Sets the data_center_id of this CreateNetworkBody.


        :param data_center_id: The data_center_id of this CreateNetworkBody.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and data_center_id is None:
            raise ValueError("Invalid value for `data_center_id`, must not be `None`")  # noqa: E501

        self._data_center_id = data_center_id

    @property
    def id(self):
        """Gets the id of this CreateNetworkBody.  # noqa: E501


        :return: The id of this CreateNetworkBody.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this CreateNetworkBody.


        :param id: The id of this CreateNetworkBody.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def network_id(self):
        """Gets the network_id of this CreateNetworkBody.  # noqa: E501


        :return: The network_id of this CreateNetworkBody.  # noqa: E501
        :rtype: str
        """
        return self._network_id

    @network_id.setter
    def network_id(self, network_id):
        """Sets the network_id of this CreateNetworkBody.


        :param network_id: The network_id of this CreateNetworkBody.  # noqa: E501
        :type: str
        """
        if self._configuration.client_side_validation and network_id is None:
            raise ValueError("Invalid value for `network_id`, must not be `None`")  # noqa: E501

        self._network_id = network_id

    @property
    def vrouter_size(self):
        """Gets the vrouter_size of this CreateNetworkBody.  # noqa: E501


        :return: The vrouter_size of this CreateNetworkBody.  # noqa: E501
        :rtype: VRouterSize
        """
        return self._vrouter_size

    @vrouter_size.setter
    def vrouter_size(self, vrouter_size):
        """Sets the vrouter_size of this CreateNetworkBody.


        :param vrouter_size: The vrouter_size of this CreateNetworkBody.  # noqa: E501
        :type: VRouterSize
        """

        self._vrouter_size = vrouter_size

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateNetworkBody, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateNetworkBody):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateNetworkBody):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from src.cudo_compute.api_client import ApiClient


class ProjectsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_project(self, project, **kwargs):  # noqa: E501
        """Create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_project(project, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Project project: (required)
        :return: Project
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_project_with_http_info(project, **kwargs)  # noqa: E501
        else:
            (data) = self.create_project_with_http_info(project, **kwargs)  # noqa: E501
            return data

    def create_project_with_http_info(self, project, **kwargs):  # noqa: E501
        """Create  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_project_with_http_info(project, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param Project project: (required)
        :return: Project
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project' is set
        if self.api_client.client_side_validation and ('project' not in params or
                                                       params['project'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project` when calling `create_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'project' in params:
            body_params = params['project']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Project',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_project(self, id, **kwargs):  # noqa: E501
        """Delete  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_project(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_project_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_project_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_project_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_project_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_project(self, id, **kwargs):  # noqa: E501
        """Get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_project(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: Project
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_project_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_project_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_project_with_http_info(self, id, **kwargs):  # noqa: E501
        """Get  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_project_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :return: Project
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Project',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_project_ssh_keys(self, project_id, **kwargs):  # noqa: E501
        """List SSH keys  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_project_ssh_keys(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :return: ListProjectSshKeysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_project_ssh_keys_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_project_ssh_keys_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def list_project_ssh_keys_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """List SSH keys  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_project_ssh_keys_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :return: ListProjectSshKeysResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_project_ssh_keys" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `list_project_ssh_keys`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/project/{projectId}/ssh-keys', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListProjectSshKeysResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_projects(self, **kwargs):  # noqa: E501
        """List  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_projects(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_token:
        :param int page_size:
        :return: ListProjectsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_projects_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_projects_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_projects_with_http_info(self, **kwargs):  # noqa: E501
        """List  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_projects_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str page_token:
        :param int page_size:
        :return: ListProjectsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_token', 'page_size']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_projects" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page_token' in params:
            query_params.append(('pageToken', params['page_token']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListProjectsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_project(self, project_id, project, **kwargs):  # noqa: E501
        """Update  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_project(project_id, project, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param Project project: (required)
        :return: Project
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_project_with_http_info(project_id, project, **kwargs)  # noqa: E501
        else:
            (data) = self.update_project_with_http_info(project_id, project, **kwargs)  # noqa: E501
            return data

    def update_project_with_http_info(self, project_id, project, **kwargs):  # noqa: E501
        """Update  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_project_with_http_info(project_id, project, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param Project project: (required)
        :return: Project
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'project']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_project" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `update_project`")  # noqa: E501
        # verify the required parameter 'project' is set
        if self.api_client.client_side_validation and ('project' not in params or
                                                       params['project'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project` when calling `update_project`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['project.id'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'project' in params:
            body_params = params['project']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{project.id}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='Project',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Cudo Compute service

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from src.cudo_compute.api_client import ApiClient


class DisksApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def attach_storage_disk(self, project_id, id, **kwargs):  # noqa: E501
        """Attach storage disk to VM  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.attach_storage_disk(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str vm_id:
        :return: AttachStorageDiskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.attach_storage_disk_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.attach_storage_disk_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def attach_storage_disk_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Attach storage disk to VM  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.attach_storage_disk_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str vm_id:
        :return: AttachStorageDiskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'vm_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method attach_storage_disk" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `attach_storage_disk`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `attach_storage_disk`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'vm_id' in params:
            query_params.append(('vmId', params['vm_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/disk/{id}/attach', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='AttachStorageDiskResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_disk_snapshot(self, project_id, id, create_disk_snapshot_body, **kwargs):  # noqa: E501
        """Create Disk Snapshot  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_disk_snapshot(project_id, id, create_disk_snapshot_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param CreateDiskSnapshotBody create_disk_snapshot_body: (required)
        :return: CreateDiskSnapshotResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_disk_snapshot_with_http_info(project_id, id, create_disk_snapshot_body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_disk_snapshot_with_http_info(project_id, id, create_disk_snapshot_body, **kwargs)  # noqa: E501
            return data

    def create_disk_snapshot_with_http_info(self, project_id, id, create_disk_snapshot_body, **kwargs):  # noqa: E501
        """Create Disk Snapshot  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_disk_snapshot_with_http_info(project_id, id, create_disk_snapshot_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param CreateDiskSnapshotBody create_disk_snapshot_body: (required)
        :return: CreateDiskSnapshotResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'create_disk_snapshot_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_disk_snapshot" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `create_disk_snapshot`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `create_disk_snapshot`")  # noqa: E501
        # verify the required parameter 'create_disk_snapshot_body' is set
        if self.api_client.client_side_validation and ('create_disk_snapshot_body' not in params or
                                                       params['create_disk_snapshot_body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_disk_snapshot_body` when calling `create_disk_snapshot`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_disk_snapshot_body' in params:
            body_params = params['create_disk_snapshot_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/disks/{id}/snapshots', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateDiskSnapshotResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_storage_disk(self, project_id, create_storage_disk_body, **kwargs):  # noqa: E501
        """Create storage disk  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_storage_disk(project_id, create_storage_disk_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param CreateStorageDiskBody create_storage_disk_body: (required)
        :return: CreateStorageDiskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_storage_disk_with_http_info(project_id, create_storage_disk_body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_storage_disk_with_http_info(project_id, create_storage_disk_body, **kwargs)  # noqa: E501
            return data

    def create_storage_disk_with_http_info(self, project_id, create_storage_disk_body, **kwargs):  # noqa: E501
        """Create storage disk  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_storage_disk_with_http_info(project_id, create_storage_disk_body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param CreateStorageDiskBody create_storage_disk_body: (required)
        :return: CreateStorageDiskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'create_storage_disk_body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_storage_disk" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `create_storage_disk`")  # noqa: E501
        # verify the required parameter 'create_storage_disk_body' is set
        if self.api_client.client_side_validation and ('create_storage_disk_body' not in params or
                                                       params['create_storage_disk_body'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `create_storage_disk_body` when calling `create_storage_disk`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'create_storage_disk_body' in params:
            body_params = params['create_storage_disk_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/disks', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CreateStorageDiskResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_disk_snapshot(self, project_id, id, snapshot_id, vm_id, **kwargs):  # noqa: E501
        """Delete Disk Snapshots  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_disk_snapshot(project_id, id, snapshot_id, vm_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str snapshot_id: (required)
        :param str vm_id: (required)
        :return: DeleteDiskSnapshotResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_disk_snapshot_with_http_info(project_id, id, snapshot_id, vm_id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_disk_snapshot_with_http_info(project_id, id, snapshot_id, vm_id, **kwargs)  # noqa: E501
            return data

    def delete_disk_snapshot_with_http_info(self, project_id, id, snapshot_id, vm_id, **kwargs):  # noqa: E501
        """Delete Disk Snapshots  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_disk_snapshot_with_http_info(project_id, id, snapshot_id, vm_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str snapshot_id: (required)
        :param str vm_id: (required)
        :return: DeleteDiskSnapshotResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'snapshot_id', 'vm_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_disk_snapshot" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `delete_disk_snapshot`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_disk_snapshot`")  # noqa: E501
        # verify the required parameter 'snapshot_id' is set
        if self.api_client.client_side_validation and ('snapshot_id' not in params or
                                                       params['snapshot_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `snapshot_id` when calling `delete_disk_snapshot`")  # noqa: E501
        # verify the required parameter 'vm_id' is set
        if self.api_client.client_side_validation and ('vm_id' not in params or
                                                       params['vm_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vm_id` when calling `delete_disk_snapshot`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'snapshot_id' in params:
            query_params.append(('snapshotId', params['snapshot_id']))  # noqa: E501
        if 'vm_id' in params:
            query_params.append(('vmId', params['vm_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/disks/{id}/snapshots', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteDiskSnapshotResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_storage_disk(self, project_id, id, **kwargs):  # noqa: E501
        """Delete storage disk  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_storage_disk(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: DeleteStorageDiskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_storage_disk_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_storage_disk_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def delete_storage_disk_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Delete storage disk  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_storage_disk_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: DeleteStorageDiskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_storage_disk" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `delete_storage_disk`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `delete_storage_disk`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/disks/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DeleteStorageDiskResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def detach_storage_disk(self, project_id, id, **kwargs):  # noqa: E501
        """Detach storage disk from VM  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.detach_storage_disk(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: DetachStorageDiskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.detach_storage_disk_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.detach_storage_disk_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def detach_storage_disk_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """Detach storage disk from VM  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.detach_storage_disk_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: DetachStorageDiskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method detach_storage_disk" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `detach_storage_disk`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `detach_storage_disk`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/disk/{id}/detach', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='DetachStorageDiskResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_disk(self, project_id, id, **kwargs):  # noqa: E501
        """List disks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_disk(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: GetDiskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_disk_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_disk_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def get_disk_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """List disks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_disk_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: GetDiskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_disk" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `get_disk`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `get_disk`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/disks/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetDiskResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_disk_snapshots(self, project_id, id, **kwargs):  # noqa: E501
        """List Disk Snapshots  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_disk_snapshots(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: ListDiskSnapshotsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_disk_snapshots_with_http_info(project_id, id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_disk_snapshots_with_http_info(project_id, id, **kwargs)  # noqa: E501
            return data

    def list_disk_snapshots_with_http_info(self, project_id, id, **kwargs):  # noqa: E501
        """List Disk Snapshots  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_disk_snapshots_with_http_info(project_id, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :return: ListDiskSnapshotsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_disk_snapshots" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `list_disk_snapshots`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `list_disk_snapshots`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/disks/{id}/snapshots', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListDiskSnapshotsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_disks(self, project_id, **kwargs):  # noqa: E501
        """List disks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_disks(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param int page_number:
        :param int page_size:
        :param str data_center_id:
        :return: ListDisksResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_disks_with_http_info(project_id, **kwargs)  # noqa: E501
        else:
            (data) = self.list_disks_with_http_info(project_id, **kwargs)  # noqa: E501
            return data

    def list_disks_with_http_info(self, project_id, **kwargs):  # noqa: E501
        """List disks  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_disks_with_http_info(project_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param int page_number:
        :param int page_size:
        :param str data_center_id:
        :return: ListDisksResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'page_number', 'page_size', 'data_center_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_disks" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `list_disks`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501

        query_params = []
        if 'page_number' in params:
            query_params.append(('pageNumber', params['page_number']))  # noqa: E501
        if 'page_size' in params:
            query_params.append(('pageSize', params['page_size']))  # noqa: E501
        if 'data_center_id' in params:
            query_params.append(('dataCenterId', params['data_center_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/disks', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ListDisksResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def revert_disk(self, project_id, id, snapshot_id, vm_id, **kwargs):  # noqa: E501
        """Revert Disk to Snapshot  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revert_disk(project_id, id, snapshot_id, vm_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str snapshot_id: (required)
        :param str vm_id: (required)
        :return: RevertDiskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.revert_disk_with_http_info(project_id, id, snapshot_id, vm_id, **kwargs)  # noqa: E501
        else:
            (data) = self.revert_disk_with_http_info(project_id, id, snapshot_id, vm_id, **kwargs)  # noqa: E501
            return data

    def revert_disk_with_http_info(self, project_id, id, snapshot_id, vm_id, **kwargs):  # noqa: E501
        """Revert Disk to Snapshot  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.revert_disk_with_http_info(project_id, id, snapshot_id, vm_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str project_id: (required)
        :param str id: (required)
        :param str snapshot_id: (required)
        :param str vm_id: (required)
        :return: RevertDiskResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['project_id', 'id', 'snapshot_id', 'vm_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method revert_disk" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'project_id' is set
        if self.api_client.client_side_validation and ('project_id' not in params or
                                                       params['project_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `project_id` when calling `revert_disk`")  # noqa: E501
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ('id' not in params or
                                                       params['id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `id` when calling `revert_disk`")  # noqa: E501
        # verify the required parameter 'snapshot_id' is set
        if self.api_client.client_side_validation and ('snapshot_id' not in params or
                                                       params['snapshot_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `snapshot_id` when calling `revert_disk`")  # noqa: E501
        # verify the required parameter 'vm_id' is set
        if self.api_client.client_side_validation and ('vm_id' not in params or
                                                       params['vm_id'] is None):  # noqa: E501
            raise ValueError("Missing the required parameter `vm_id` when calling `revert_disk`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'project_id' in params:
            path_params['projectId'] = params['project_id']  # noqa: E501
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []
        if 'snapshot_id' in params:
            query_params.append(('snapshotId', params['snapshot_id']))  # noqa: E501
        if 'vm_id' in params:
            query_params.append(('vmId', params['vm_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v1/projects/{projectId}/disks/{id}/revert', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='RevertDiskResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)
